@@ -6,9 +6,7 @@
 # the MIT License: https://www.opensource.org/licenses/mit-license.php
 
 
-"""Base constructs for connection pools.
-
-"""
+"""Base constructs for connection pools."""
 
 from __future__ import annotations
 
@@ -1079,6 +1077,8 @@ class PoolProxiedConnection(ManagesConnection):
 
         def rollback(self) -> None: ...
 
+        def __getattr__(self, key: str) -> Any: ...
+
     @property
     def is_valid(self) -> bool:
         """Return True if this :class:`.PoolProxiedConnection` still refers
