@@ -21,6 +21,7 @@ from sqlalchemy import Table
 from sqlalchemy import testing
 from sqlalchemy import text
 from sqlalchemy import true
+from sqlalchemy.dialects.mysql import TIMESTAMP
 from sqlalchemy.testing import assert_raises
 from sqlalchemy.testing import combinations
 from sqlalchemy.testing import eq_
@@ -56,6 +57,9 @@ class IdiosyncrasyTest(fixtures.TestBase):
 
 
 class ServerDefaultCreateTest(fixtures.TestBase):
+    __only_on__ = "mysql", "mariadb"
+    __backend__ = True
+
     @testing.combinations(
         (Integer, text("10")),
         (Integer, text("'10'")),
@@ -70,6 +74,28 @@ class ServerDefaultCreateTest(fixtures.TestBase):
             literal_column("3") + literal_column("5"),
             testing.requires.mysql_expression_defaults,
         ),
+        (
+            DateTime,
+            text("now() ON UPDATE now()"),
+        ),
+        (
+            DateTime,
+            text("now() on update now()"),
+        ),
+        (
+            DateTime,
+            text("now() ON   UPDATE now()"),
+        ),
+        (
+            TIMESTAMP(fsp=3),
+            text("now(3)"),
+            testing.requires.mysql_fsp,
+        ),
+        (
+            TIMESTAMP(fsp=3),
+            text("CURRENT_TIMESTAMP(3)"),
+            testing.requires.mysql_fsp,
+        ),
         argnames="datatype, default",
     )
     def test_create_server_defaults(
