@@ -21,6 +21,11 @@ from sqlalchemy import text
 from sqlalchemy import Unicode
 from sqlalchemy import UniqueConstraint
 from sqlalchemy.dialects import oracle
+from sqlalchemy.dialects.oracle import VECTOR
+from sqlalchemy.dialects.oracle import VectorDistanceType
+from sqlalchemy.dialects.oracle import VectorIndexConfig
+from sqlalchemy.dialects.oracle import VectorIndexType
+from sqlalchemy.dialects.oracle import VectorStorageFormat
 from sqlalchemy.dialects.oracle.base import BINARY_DOUBLE
 from sqlalchemy.dialects.oracle.base import BINARY_FLOAT
 from sqlalchemy.dialects.oracle.base import DOUBLE_PRECISION
@@ -50,7 +55,7 @@ from sqlalchemy.testing.schema import Table
 
 class MultiSchemaTest(fixtures.TestBase, AssertsCompiledSQL):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_test_class(cls):
@@ -349,7 +354,7 @@ class MultiSchemaTest(fixtures.TestBase, AssertsCompiledSQL):
 
 class ConstraintTest(AssertsCompiledSQL, fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @testing.fixture
     def plain_foo_table(self, metadata, connection):
@@ -539,7 +544,7 @@ class ConstraintTest(AssertsCompiledSQL, fixtures.TestBase):
 
 class SystemTableTablenamesTest(fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def setup_test(self):
         with testing.db.begin() as conn:
@@ -589,7 +594,7 @@ class DontReflectIOTTest(fixtures.TestBase):
     table_names."""
 
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def setup_test(self):
         with testing.db.begin() as conn:
@@ -634,7 +639,7 @@ def enterprise_edition_or_version(version):
 
 class TableReflectionTest(fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @testing.only_on(enterprise_edition_or_version(18))
     def test_reflect_basic_compression(self, metadata, connection):
@@ -698,10 +703,29 @@ class TableReflectionTest(fixtures.TestBase):
         tbl = Table("test_tablespace", m2, autoload_with=connection)
         assert tbl.dialect_options["oracle"]["tablespace"] == "TEMP"
 
+    @testing.only_on("oracle>=23.4")
+    def test_reflection_w_vector_column(self, connection, metadata):
+        tb1 = Table(
+            "test_vector",
+            metadata,
+            Column("id", Integer, primary_key=True),
+            Column("name", String(30)),
+            Column(
+                "embedding",
+                VECTOR(dim=3, storage_format=VectorStorageFormat.FLOAT32),
+            ),
+        )
+        metadata.create_all(connection)
+
+        m2 = MetaData()
+
+        tb1 = Table("test_vector", m2, autoload_with=connection)
+        assert tb1.columns.keys() == ["id", "name", "embedding"]
+
 
 class ViewReflectionTest(fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_test_class(cls):
@@ -909,7 +933,7 @@ class ViewReflectionTest(fixtures.TestBase):
 
 class RoundTripIndexTest(fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def test_no_pk(self, metadata, connection):
         Table(
@@ -1180,11 +1204,47 @@ class RoundTripIndexTest(fixtures.TestBase):
         eq_(len(reflectedtable.constraints), 1)
         eq_(len(reflectedtable.indexes), 5)
 
+    @testing.only_on("oracle>=23.4")
+    def test_vector_index(self, metadata, connection):
+        tb1 = Table(
+            "test_vector",
+            metadata,
+            Column("id", Integer, primary_key=True),
+            Column("name", String(30)),
+            Column(
+                "embedding",
+                VECTOR(dim=3, storage_format=VectorStorageFormat.FLOAT32),
+            ),
+        )
+        tb1.create(connection)
+
+        ivf_index = Index(
+            "ivf_vector_index",
+            tb1.c.embedding,
+            oracle_vector=VectorIndexConfig(
+                index_type=VectorIndexType.IVF,
+                distance=VectorDistanceType.DOT,
+                accuracy=90,
+                ivf_neighbor_partitions=5,
+            ),
+        )
+        ivf_index.create(connection)
+
+        expected = [
+            {
+                "name": "ivf_vector_index",
+                "column_names": ["embedding"],
+                "dialect_options": {},
+                "unique": False,
+            },
+        ]
+        eq_(inspect(connection).get_indexes("test_vector"), expected)
+
 
 class DBLinkReflectionTest(fixtures.TestBase):
     __requires__ = ("oracle_test_dblink",)
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_test_class(cls):
@@ -1225,7 +1285,7 @@ class DBLinkReflectionTest(fixtures.TestBase):
 
 class TypeReflectionTest(fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def _run_test(self, metadata, connection, specs, attributes):
         columns = [Column("c%i" % (i + 1), t[0]) for i, t in enumerate(specs)]
@@ -1323,7 +1383,7 @@ class TypeReflectionTest(fixtures.TestBase):
 
 class IdentityReflectionTest(fixtures.TablesTest):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
     __requires__ = ("identity_columns",)
 
     @classmethod
@@ -1359,7 +1419,7 @@ class IdentityReflectionTest(fixtures.TablesTest):
 
 class AdditionalReflectionTests(fixtures.TestBase):
     __only_on__ = "oracle"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_test_class(cls):
