@@ -45,7 +45,7 @@ from sqlalchemy.testing.assertsql import DialectSQL
 
 class FunctionTypingTest(fixtures.TestBase, AssertsExecutionResults):
     __only_on__ = "postgresql"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def test_count_star(self, connection):
         eq_(connection.scalar(func.count("*")), 1)
@@ -161,6 +161,104 @@ class InsertTest(fixtures.TestBase, AssertsExecutionResults):
         metadata.create_all(connection)
         self._assert_data_noautoincrement(connection, table)
 
+    def test_full_cursor_insertmanyvalues_sql(self, metadata, connection):
+        """test compilation/ execution of the subquery form including
+        the fix for #13015
+
+        The specific form in question for #13015 is only supported by the
+        PostgreSQL dialect right now.   MSSQL would also use it for a server
+        side function that produces monotonic values, but we have no support
+        for that outside of sequence next right now, where SQL Server doesn't
+        support invokving the sequence outside of the VALUES tuples.
+
+        """
+
+        my_table = Table(
+            "my_table",
+            metadata,
+            Column("data1", String(50)),
+            Column(
+                "id",
+                Integer,
+                Sequence("foo_id_seq", start=1, data_type=Integer),
+                primary_key=True,
+            ),
+            Column("data2", String(50)),
+        )
+
+        my_table.create(connection)
+        with self.sql_execution_asserter(connection) as assert_:
+            connection.execute(
+                my_table.insert().returning(
+                    my_table.c.data1,
+                    my_table.c.id,
+                    sort_by_parameter_order=True,
+                ),
+                [
+                    {"data1": f"d1 row {i}", "data2": f"d2 row {i}"}
+                    for i in range(10)
+                ],
+            )
+
+        render_bind_casts = (
+            String().dialect_impl(connection.dialect).render_bind_cast
+        )
+
+        if render_bind_casts:
+            varchar_cast = "::VARCHAR"
+        else:
+            varchar_cast = ""
+
+        if connection.dialect.paramstyle == "pyformat":
+            params = ", ".join(
+                f"(%(data1__{i})s{varchar_cast}, %(data2__{i})s"
+                f"{varchar_cast}, {i})"
+                for i in range(0, 10)
+            )
+            parameters = {}
+            for i in range(10):
+                parameters[f"data1__{i}"] = f"d1 row {i}"
+                parameters[f"data2__{i}"] = f"d2 row {i}"
+
+        elif connection.dialect.paramstyle == "numeric_dollar":
+            params = ", ".join(
+                f"(${i * 2 + 1}{varchar_cast}, "
+                f"${i * 2 + 2}{varchar_cast}, {i})"
+                for i in range(0, 10)
+            )
+            parameters = ()
+            for i in range(10):
+                parameters += (f"d1 row {i}", f"d2 row {i}")
+        elif connection.dialect.paramstyle == "format":
+            params = ", ".join(
+                f"(%s{varchar_cast}, %s{varchar_cast}, {i})"
+                for i in range(0, 10)
+            )
+            parameters = ()
+            for i in range(10):
+                parameters += (f"d1 row {i}", f"d2 row {i}")
+        elif connection.dialect.paramstyle == "qmark":
+            params = ", ".join(
+                f"(?{varchar_cast}, ?{varchar_cast}, {i})"
+                for i in range(0, 10)
+            )
+            parameters = ()
+            for i in range(10):
+                parameters += (f"d1 row {i}", f"d2 row {i}")
+        else:
+            assert False
+
+        assert_.assert_(
+            CursorSQL(
+                "INSERT INTO my_table (data1, id, data2) "
+                f"SELECT p0::VARCHAR, nextval('foo_id_seq'), p2::VARCHAR "
+                f"FROM (VALUES {params}) "
+                "AS imp_sen(p0, p2, sen_counter) ORDER BY sen_counter "
+                "RETURNING my_table.data1, my_table.id, my_table.id AS id__1",
+                parameters,
+            )
+        )
+
     def _ints_and_strs_setinputsizes(self, connection):
         return (
             connection.dialect._bind_typing_render_casts
@@ -1007,7 +1105,7 @@ class MatchTest(fixtures.TablesTest, AssertsCompiledSQL):
         (func.to_tsquery,),
         (func.plainto_tsquery,),
         (func.phraseto_tsquery,),
-        (func.websearch_to_tsquery,),
+        (func.websearch_to_tsquery, testing.skip_if("postgresql < 11")),
         argnames="to_ts_func",
     )
     @testing.variation("use_regconfig", [True, False, "literal"])
@@ -1799,7 +1897,12 @@ class TableValuedRoundTripTest(fixtures.TestBase):
         eq_(connection.execute(stmt).all(), [(1, "foo"), (2, "bar")])
 
 
-class RequiresCastTest(fixtures.TablesTest):
+class JSONUpdateTest(fixtures.TablesTest):
+    """round trip tests related to using JSON and JSONB in UPDATE statements
+    with PG-specific features
+
+    """
+
     __only_on__ = "postgresql"
     __backend__ = True
 
@@ -1825,6 +1928,8 @@ class RequiresCastTest(fixtures.TablesTest):
         )
 
     def test_update_values(self, connection):
+        t = self.tables["t"]
+
         value = values(
             Column("id", Integer),
             Column("uuid", Uuid),
@@ -1848,8 +1953,149 @@ class RequiresCastTest(fixtures.TablesTest):
             ]
         )
         connection.execute(
-            self.tables["t"]
-            .update()
+            t.update()
             .values(uuid=value.c.uuid, j=value.c.j, jb=value.c.jb)
-            .where(self.tables["t"].c.id == value.c.id)
+            .where(t.c.id == value.c.id)
+        )
+
+        updated_data = connection.execute(t.select().order_by(t.c.id))
+        eq_(
+            [(str(row.uuid), row.j, row.jb) for row in updated_data],
+            [
+                (
+                    "8b6ec1ec-b979-4d0b-b2ce-9acc6e4c2943",
+                    {"foo": 1},
+                    {"foo_jb": 1},
+                ),
+                (
+                    "a2123bcb-7ea3-420a-8284-1db4b2759d79",
+                    {"bar": 2},
+                    {"bar_jb": 2},
+                ),
+            ],
+        )
+
+    @testing.only_on("postgresql>=14")
+    def test_jsonb_element_update_basic(self, connection):
+        """Test updating individual JSONB elements with subscript syntax
+
+        test #10927
+
+        """
+        t = self.tables["t"]
+
+        # Insert test data with complex JSONB
+        connection.execute(
+            t.insert(),
+            [
+                {
+                    "id": 10,
+                    "jb": {
+                        "user": {"name": "Alice", "age": 30},
+                        "active": True,
+                    },
+                },
+                {
+                    "id": 11,
+                    "jb": {
+                        "user": {"name": "Bob", "age": 25},
+                        "active": False,
+                    },
+                },
+            ],
+        )
+
+        # Update specific elements using JSONB subscript syntax
+        # This tests the new JSONB subscripting feature from issue #10927
+        connection.execute(
+            t.update()
+            .values({t.c.jb["user"]["name"]: "Alice Updated"})
+            .where(t.c.id == 10)
+        )
+
+        connection.execute(
+            t.update().values({t.c.jb["active"]: True}).where(t.c.id == 11)
+        )
+
+        results = connection.execute(
+            t.select().where(t.c.id.in_([10, 11])).order_by(t.c.id)
+        )
+
+        eq_(
+            [row.jb for row in results],
+            [
+                {"user": {"name": "Alice Updated", "age": 30}, "active": True},
+                {"user": {"name": "Bob", "age": 25}, "active": True},
+            ],
+        )
+
+    @testing.only_on("postgresql>=14")
+    def test_jsonb_element_update_multiple_keys(self, connection):
+        """Test updating multiple JSONB elements in a single statement
+
+        test #10927
+
+        """
+        t = self.tables["t"]
+
+        connection.execute(
+            t.insert(),
+            {
+                "id": 20,
+                "jb": {
+                    "config": {"theme": "dark", "lang": "en"},
+                    "version": 1,
+                },
+            },
+        )
+
+        # Update multiple elements at once
+        connection.execute(
+            t.update()
+            .values({t.c.jb["config"]["theme"]: "light", t.c.jb["version"]: 2})
+            .where(t.c.id == 20)
+        )
+
+        # Verify the updates
+        row = connection.execute(t.select().where(t.c.id == 20)).one()
+
+        eq_(
+            row.jb,
+            {"config": {"theme": "light", "lang": "en"}, "version": 2},
+        )
+
+    @testing.only_on("postgresql>=14")
+    def test_jsonb_element_update_array_element(self, connection):
+        """Test updating JSONB array elements
+
+        test #10927
+
+        """
+        t = self.tables["t"]
+
+        # Insert test data with arrays
+        connection.execute(
+            t.insert(),
+            {
+                "id": 30,
+                "jb": {
+                    "tags": ["python", "sql", "postgres"],
+                    "priority": "high",
+                },
+            },
+        )
+
+        # Update array element
+        connection.execute(
+            t.update()
+            .values({t.c.jb["tags"][1]: "postgresql"})
+            .where(t.c.id == 30)
+        )
+
+        # Verify the update
+        row = connection.execute(t.select().where(t.c.id == 30)).fetchone()
+
+        eq_(
+            row.jb,
+            {"tags": ["python", "postgresql", "postgres"], "priority": "high"},
         )
