@@ -967,6 +967,7 @@ class PoolFirstConnectSyncTest(PoolTestBase):
             evt.connect()
 
         def checkout():
+            barrier.wait()
             for j in range(2):
                 c1 = pool.connect()
                 time.sleep(0.02)
@@ -981,6 +982,7 @@ class PoolFirstConnectSyncTest(PoolTestBase):
         # any of the connections get returned.   so first_connect()
         # sleeps for one second, then pings the mock.  the threads should
         # not have made it to the "checkout() event for that one second.
+        barrier = threading.Barrier(5)
         for i in range(5):
             th = threading.Thread(target=checkout)
             th.start()
@@ -1081,16 +1083,32 @@ class QueuePoolTest(PoolTestBase):
         assert_raises(tsa.exc.TimeoutError, p.connect)
         assert int(time.time() - now) == 2
 
-    @testing.requires.timing_intensive
     def test_timeout_subsecond_precision(self):
-        p = self._queuepool_fixture(pool_size=1, max_overflow=0, timeout=0.5)
-        c1 = p.connect()  # noqa
-        with expect_raises(tsa.exc.TimeoutError):
-            now = time.time()
-            c2 = p.connect()  # noqa
-        # Python timing is not very accurate, the time diff should be very
-        # close to 0.5s but we give 200ms of slack.
-        assert 0.3 <= time.time() - now <= 0.7, "Pool timeout not respected"
+        """test that a subsecond precision is passed to queue.get()
+        and that the math comparison is float sensitive
+
+        """
+        times = [
+            # will set endtime at 1761659753.1250672 + .5
+            1761659753.1250672,
+            # will be within the timeout
+            1761659753.349,
+            # will be outside the timeout, should raise Empty
+            # if the timeout is a whole number, then this would not be
+            # enough time to wait and we get "pop from an empty list"
+            1761659753.715,
+        ]
+
+        def mock_time():
+            return times.pop(0)
+
+        with mock.patch("sqlalchemy.util.queue._time", mock_time):
+            p = self._queuepool_fixture(
+                pool_size=1, max_overflow=0, timeout=0.5
+            )
+            c1 = p.connect()  # noqa
+            with expect_raises(tsa.exc.TimeoutError):
+                p.connect()
 
     @testing.requires.threading_with_mock
     @testing.requires.timing_intensive
@@ -1112,6 +1130,7 @@ class QueuePoolTest(PoolTestBase):
         timeouts = []
 
         def checkout():
+            barrier.wait()
             for x in range(1):
                 now = time.time()
                 try:
@@ -1122,6 +1141,7 @@ class QueuePoolTest(PoolTestBase):
                 time.sleep(4)
                 c1.close()
 
+        barrier = threading.Barrier(10)
         threads = []
         for i in range(10):
             th = threading.Thread(target=checkout)
