@@ -47,7 +47,7 @@ from sqlalchemy.testing.schema import Table
 
 
 class ReflectionTest(fixtures.TestBase, ComparesTables):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def test_basic_reflection(self, connection, metadata):
         meta = metadata
@@ -249,6 +249,27 @@ class ReflectionTest(fixtures.TestBase, ComparesTables):
         t2 = meta2.tables["t2"]
         is_true(t1.c.t2id.references(t2.c.id))
 
+    @testing.combinations(
+        "get_table_names",
+        "get_view_names",
+        "get_materialized_view_names",
+        argnames="method",
+    )
+    def test_reflect_forwards_multiple_kwargs(
+        self, connection, metadata, method
+    ):
+        with mock.patch(
+            f"sqlalchemy.engine.reflection.Inspector.{method}",
+            return_value=set(),
+        ) as mocked_method:
+            metadata.reflect(
+                bind=connection, flag1=True, flag2=123, flag3="abc", views=True
+            )
+
+            mocked_method.assert_called_once_with(
+                None, flag1=True, flag2=123, flag3="abc"
+            )
+
     def test_nonexistent(self, connection):
         meta = MetaData()
         assert_raises(
@@ -1462,7 +1483,7 @@ class ReflectionTest(fixtures.TestBase, ComparesTables):
 
 
 class CreateDropTest(fixtures.TablesTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     run_create_tables = None
 
@@ -1608,7 +1629,7 @@ class CreateDropTest(fixtures.TablesTest):
 
 
 class SchemaManipulationTest(fixtures.TestBase):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def test_append_constraint_unique(self):
         meta = MetaData()
@@ -1630,7 +1651,7 @@ class SchemaManipulationTest(fixtures.TestBase):
 
 
 class UnicodeReflectionTest(fixtures.TablesTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -1753,7 +1774,7 @@ class UnicodeReflectionTest(fixtures.TablesTest):
 
 
 class SchemaTest(fixtures.TestBase):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @testing.requires.schemas
     def test_has_schema(self):
@@ -2016,7 +2037,7 @@ def _drop_views(conn, schema=None):
 
 class ReverseCasingReflectTest(fixtures.TestBase, AssertsCompiledSQL):
     __dialect__ = "default"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @testing.requires.denormalized_names
     def setup_test(self):
@@ -2051,7 +2072,7 @@ class ReverseCasingReflectTest(fixtures.TestBase, AssertsCompiledSQL):
 class CaseSensitiveTest(fixtures.TablesTest):
     """Nail down case sensitive behaviors, mostly on MySQL."""
 
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -2099,7 +2120,7 @@ class CaseSensitiveTest(fixtures.TablesTest):
 
 
 class ColumnEventsTest(fixtures.RemovesEvents, fixtures.TablesTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -2322,7 +2343,7 @@ class ComputedColumnTest(fixtures.ComputedReflectionFixtureTest):
 class IdentityColumnTest(fixtures.TablesTest):
     run_inserts = run_deletes = None
 
-    __backend__ = True
+    __sparse_driver_backend__ = True
     __requires__ = ("identity_columns", "table_reflection")
 
     @classmethod
