@@ -15,8 +15,10 @@ from sqlalchemy import String
 from sqlalchemy import testing
 from sqlalchemy import TypeDecorator
 from sqlalchemy import util
+from sqlalchemy import Uuid
 from sqlalchemy.orm import configure_mappers
 from sqlalchemy.orm import exc as orm_exc
+from sqlalchemy.orm import mapped_column
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm import Session
 from sqlalchemy.testing import assert_raises
@@ -30,6 +32,7 @@ from sqlalchemy.testing import expect_warnings
 from sqlalchemy.testing import fixtures
 from sqlalchemy.testing import is_false
 from sqlalchemy.testing import is_true
+from sqlalchemy.testing import provision
 from sqlalchemy.testing.assertsql import CompiledSQL
 from sqlalchemy.testing.fixtures import fixture_session
 from sqlalchemy.testing.schema import Column
@@ -64,7 +67,7 @@ def conditional_sane_rowcount_warnings(
 
 
 class NullVersionIdTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -145,7 +148,7 @@ class NullVersionIdTest(fixtures.MappedTest):
 
 
 class VersioningTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -192,6 +195,7 @@ class VersioningTest(fixtures.MappedTest):
         finally:
             testing.db.dialect.supports_sane_rowcount = save
 
+    @provision.allow_stale_updates
     def test_basic(self):
         Foo = self.classes.Foo
 
@@ -339,6 +343,7 @@ class VersioningTest(fixtures.MappedTest):
             s1.commit()
         eq_(s1.query(Foo).count(), 0)
 
+    @provision.allow_stale_updates
     @engines.close_open_connections
     def test_versioncheck(self):
         """query.with_lockmode performs a 'version check' on an already loaded
@@ -582,7 +587,7 @@ class VersioningTest(fixtures.MappedTest):
 
 
 class VersionOnPostUpdateTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -752,8 +757,50 @@ class VersionOnPostUpdateTest(fixtures.MappedTest):
         )
 
 
+class PostUpdatePrefetchTest(fixtures.DeclarativeMappedTest):
+    """test #12748"""
+
+    run_setup_classes = "each"
+
+    @classmethod
+    def setup_classes(cls):
+        Base = cls.DeclarativeBasic
+
+        class Parent(Base):
+            __tablename__ = "parent"
+            id = mapped_column(Integer, primary_key=True)
+
+            related = relationship(
+                "Related", post_update=True, cascade="all, delete-orphan"
+            )
+
+        class Related(Base):
+            __tablename__ = "related"
+
+            id = mapped_column(Integer, primary_key=True)
+            parent_id = mapped_column(ForeignKey("parent.id"))
+            version = mapped_column(Uuid)
+
+            __mapper_args__ = {
+                "version_id_col": version,
+                "version_id_generator": lambda v: uuid.uuid4(),
+            }
+
+    def test_random_versionids(self, connection):
+        Parent, Related = self.classes("Parent", "Related")
+
+        p1 = Parent(related=[Related(), Related(), Related()])
+        with Session(connection, expire_on_commit=False) as sess:
+            sess.add(p1)
+            sess.commit()
+
+        with Session(connection, expire_on_commit=False) as sess:
+            sess.delete(p1)
+            sess.commit()
+
+
 class NoBumpOnRelationshipTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -846,7 +893,7 @@ class NoBumpOnRelationshipTest(fixtures.MappedTest):
 
 
 class ColumnTypeTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
     __requires__ = ("sane_rowcount",)
 
     @classmethod
@@ -896,7 +943,7 @@ class ColumnTypeTest(fixtures.MappedTest):
 
 
 class RowSwitchTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -976,7 +1023,7 @@ class RowSwitchTest(fixtures.MappedTest):
 
 
 class AlternateGeneratorTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
     __requires__ = ("sane_rowcount",)
 
     @classmethod
@@ -1060,6 +1107,7 @@ class AlternateGeneratorTest(fixtures.MappedTest):
             session.commit()
 
     @testing.requires.sane_rowcount
+    @provision.allow_stale_updates
     def test_child_row_switch_two(self):
         P = self.classes.P
 
@@ -1096,7 +1144,7 @@ class AlternateGeneratorTest(fixtures.MappedTest):
 
 
 class PlainInheritanceTest(fixtures.MappedTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -1155,7 +1203,7 @@ class InheritanceTwoVersionIdsTest(fixtures.MappedTest):
 
     """
 
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -1283,7 +1331,7 @@ class InheritanceTwoVersionIdsTest(fixtures.MappedTest):
 class ServerVersioningTest(fixtures.MappedTest):
     run_define_tables = "each"
 
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -1628,6 +1676,7 @@ class ServerVersioningTest(fixtures.MappedTest):
             self.assert_sql_execution(testing.db, sess.flush, *statements)
 
     @testing.requires.independent_connections
+    @provision.allow_stale_updates
     def test_concurrent_mod_err_expire_on_commit(self):
         sess = self._fixture()
 
@@ -1681,7 +1730,7 @@ class ServerVersioningTest(fixtures.MappedTest):
 
 class ManualVersionTest(fixtures.MappedTest):
     run_define_tables = "each"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -1778,7 +1827,7 @@ class ManualVersionTest(fixtures.MappedTest):
 
 class ManualInheritanceVersionTest(fixtures.MappedTest):
     run_define_tables = "each"
-    __backend__ = True
+    __sparse_driver_backend__ = True
     __requires__ = ("sane_rowcount",)
 
     @classmethod
@@ -1849,7 +1898,7 @@ class ManualInheritanceVersionTest(fixtures.MappedTest):
 class VersioningMappedSelectTest(fixtures.MappedTest):
     # test for #4193, see also #4194 for related notes
 
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -1984,7 +2033,7 @@ class VersioningMappedSelectTest(fixtures.MappedTest):
 class QuotedBindVersioningTest(fixtures.MappedTest):
     """test for #8056"""
 
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
