@@ -72,6 +72,10 @@ class DefaultRequirements(SuiteRequirements):
 
         return skip_if(no_support("sqlite", "not supported by database"))
 
+    @property
+    def foreign_key_cycles_w_cascade(self):
+        return skip_if(no_support("mssql", "not supported"))
+
     @property
     def foreign_keys_reflect_as_index(self):
         return only_on(["mysql", "mariadb"])
@@ -159,6 +163,10 @@ class DefaultRequirements(SuiteRequirements):
     def fk_constraint_option_reflection_onupdate_restrict(self):
         return only_on(["postgresql", "sqlite", self._mysql_80])
 
+    @property
+    def temp_table_comment_reflection(self):
+        return only_on(["postgresql", "mysql", "mariadb", "oracle"])
+
     @property
     def comment_reflection(self):
         return only_on(["postgresql", "mysql", "mariadb", "oracle", "mssql"])
@@ -171,6 +179,10 @@ class DefaultRequirements(SuiteRequirements):
     def constraint_comment_reflection(self):
         return only_on(["postgresql"])
 
+    @property
+    def column_collation_reflection(self):
+        return only_on(["postgresql"])
+
     @property
     def unbounded_varchar(self):
         """Target database must support VARCHAR with no length"""
@@ -404,7 +416,13 @@ class DefaultRequirements(SuiteRequirements):
         gc.collect() is called, as well as clean out unreferenced subclasses.
 
         """
-        return self.cpython + skip_if("+aiosqlite")
+        return self.cpython + self.gil_enabled + skip_if("+aiosqlite")
+
+    @property
+    def multithreading_support(self):
+        """target platform allows use of threads without any problem"""
+
+        return skip_if("+aiosqlite") + skip_if(self.sqlite_memory)
 
     @property
     def memory_process_intensive(self):
@@ -415,7 +433,9 @@ class DefaultRequirements(SuiteRequirements):
         return skip_if(
             [
                 no_support("oracle", "Oracle XE usually can't handle these"),
-                no_support("mssql+pyodbc", "MS ODBC drivers struggle"),
+                no_support(
+                    "mssql", "MS drivers struggle plus the DB does too"
+                ),
                 no_support("+aiosqlite", "very unreliable driver"),
                 self._running_on_windows(),
             ]
@@ -443,6 +463,14 @@ class DefaultRequirements(SuiteRequirements):
             in self.get_isolation_levels(config)["supported"]
         )
 
+    @property
+    def skip_autocommit_rollback(self):
+        return exclusions.skip_if(
+            ["mssql+pymssql"],
+            "DBAPI has no means of testing the autocommit status of a "
+            "connection",
+        )
+
     @property
     def row_triggers(self):
         """Target must support standard statement-running EACH ROW triggers."""
@@ -655,6 +683,10 @@ class DefaultRequirements(SuiteRequirements):
             ]
         )
 
+    @property
+    def indexes_check_column_order(self):
+        return exclusions.open()
+
     @property
     def indexes_with_expressions(self):
         return only_on(["postgresql", "sqlite>=3.9.0", "oracle"])
@@ -736,6 +768,24 @@ class DefaultRequirements(SuiteRequirements):
             ]
         )
 
+    @property
+    def ctes_with_values(self):
+        return only_on(
+            [
+                lambda config: against(config, "mysql")
+                and (
+                    (
+                        config.db.dialect._is_mariadb
+                        and config.db.dialect._mariadb_normalized_version_info
+                        >= (10, 2)
+                    )
+                ),
+                "mariadb>10.2",
+                "postgresql",
+                "sqlite>=3.8.3",
+            ]
+        )
+
     @property
     def ctes_with_update_delete(self):
         """target database supports CTES that ride on top of a normal UPDATE
@@ -895,6 +945,7 @@ class DefaultRequirements(SuiteRequirements):
                 no_support(
                     "sqlite", "two-phase xact not supported by database"
                 ),
+                no_support("oracle+cx_oracle", "prefer oracledb"),
                 # in Ia3cbbf56d4882fcc7980f90519412f1711fae74d
                 # we are evaluating which modern MySQL / MariaDB versions
                 # can handle two-phase testing without too many problems
@@ -993,6 +1044,10 @@ class DefaultRequirements(SuiteRequirements):
         """
         return exclusions.open()
 
+    @property
+    def nvarchar_types(self):
+        return only_on(["mssql", "oracle", "sqlite", "mysql", "mariadb"])
+
     @property
     def unicode_data_no_special_types(self):
         """Target database/dialect can receive / deliver / compare data with
@@ -1566,6 +1621,12 @@ class DefaultRequirements(SuiteRequirements):
             )
         )
 
+    @property
+    def async_dialect_with_await_close(self):
+        """dialect's cursor has a close() method called with await"""
+
+        return only_on(["+aioodbc", "+aiomysql", "+asyncmy"])
+
     def _has_oracle_test_dblink(self, key):
         def check(config):
             assert config.db.dialect.name == "oracle"
@@ -1589,6 +1650,16 @@ class DefaultRequirements(SuiteRequirements):
     def oracle_test_dblink2(self):
         return self._has_oracle_test_dblink("oracle_db_link2")
 
+    @property
+    def oracle_vector(self):
+        """oracle vector support"""
+        return only_on("oracle>=23.4") + only_on("oracle+oracledb")
+
+    @property
+    def oracle_sparse_vector(self):
+        """oracle vector support"""
+        return only_on("oracle>=23.7") + only_on("oracle+oracledb")
+
     @property
     def postgresql_test_dblink(self):
         return skip_if(
@@ -1683,10 +1754,6 @@ class DefaultRequirements(SuiteRequirements):
     def mssql_freetds(self):
         return only_on(["mssql+pymssql"])
 
-    @property
-    def ad_hoc_engines(self):
-        return skip_if(self._sqlite_file_db)
-
     @property
     def no_asyncio(self):
         def go(config):
@@ -1729,6 +1796,10 @@ class DefaultRequirements(SuiteRequirements):
             "lock-sensitive operations crash on mysqlconnector",
         )
 
+    @property
+    def mysql_for_update_read(self):
+        return self.mysql_for_update + only_on(["mysql >= 8.0.0", "mariadb"])
+
     @property
     def mysql_fsp(self):
         return only_if(["mysql >= 5.6.4", "mariadb"])
