@@ -55,7 +55,7 @@ class ToMetaDataTest(fixtures.TestBase):
 
 
 class DeprecationWarningsTest(fixtures.TestBase, AssertsCompiledSQL):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     def test_ident_preparer_force(self):
         preparer = testing.db.dialect.identifier_preparer
@@ -550,7 +550,7 @@ class TextualSelectTest(fixtures.TestBase, AssertsCompiledSQL):
 class KeyTargetingTest(fixtures.TablesTest):
     run_inserts = "once"
     run_deletes = None
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
@@ -593,7 +593,7 @@ class KeyTargetingTest(fixtures.TablesTest):
 
 class PKIncrementTest(fixtures.TablesTest):
     run_define_tables = "each"
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
