@@ -24,7 +24,7 @@ from sqlalchemy.testing.util import picklers
 
 
 class QuoteExecTest(fixtures.TablesTest):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def define_tables(cls, metadata):
